import argparse

from rust2rpm.sysinfo import get_default_target


def get_parser() -> argparse.ArgumentParser:
    default_target = get_default_target()

    parser = argparse.ArgumentParser("rust2rpm", formatter_class=argparse.RawTextHelpFormatter)
    parser.add_argument(
        "--show-license-map",
        action="store_true",
        help="Print license mappings and exit",
    )
    parser.add_argument(
        "--translate-license",
        action="store_true",
        help="Print mapping for specified license and exit",
    )
    parser.add_argument(
        "--no-auto-changelog-entry",
        action="store_false",
        default=True,
        dest="auto_changelog_entry",
        help="Do not generate a changelog entry",
    )
    parser.add_argument(
        "--no-existence-check",
        action="store_false",
        default=True,
        dest="existence_check",
        help="Do not check whether the package already exists in dist-git",
    )
    parser.add_argument(
        "-t",
        "--target",
        action="store",
        choices=("plain", "fedora", "mageia", "opensuse"),
        default=default_target,
        help="Distribution target",
    )
    parser.add_argument(
        "--no-patch-foreign",
        action="store_false",
        default=True,
        dest="patch_foreign",
        help="Do not automatically drop foreign dependencies in Cargo.toml",
    )
    parser.add_argument(
        "-I",
        "--ignore-missing-license-files",
        action="store_true",
        default=False,
        dest="ignore_missing_license_files",
        help=argparse.SUPPRESS,
    )
    parser.add_argument(
        "-p",
        "--patch",
        action="store_true",
        help="Do manual patching of Cargo.toml",
    )
    parser.add_argument(
        "-s",
        "--store-crate",
        action="store_true",
        help="Store crate in current directory",
    )
    parser.add_argument(
        "-a",
        "--rpmautospec",
        action="store_true",
        default=None,
        help="Use autorelease and autochangelog features",
    )
    parser.add_argument(
        "--no-rpmautospec",
        action="store_false",
        dest="rpmautospec",
        help="Do not use rpmautospec",
    )
    parser.add_argument(
        "--relative-license-paths",
        action="store_true",
        help="Put all license files in main license directory",
    )
    parser.add_argument(
        "--compat",
        action="store_true",
        default=False,
        help="Create a compat package with appropriate version suffix",
    )
    parser.add_argument(
        "-i",
        "--interactive",
        action="store_true",
        help="Enable interactive mode",
    )
    parser.add_argument(
        "-V",
        "--vendor",
        action="store_true",
        help="Create a vendor tarball and write a spec for building with vendored dependencies",
    )
    parser.add_argument(
        "-l",
        "--legacy",
        action="store_true",
        help="Generate a spec file that is compatible with older versions of RPM",
    )
    parser.add_argument(
        "crate",
        help="crates.io name\n" "path/to/local.crate\n" "path/to/project/",
        nargs="?",
    )
    parser.add_argument(
        "version",
        nargs="?",
        help="crates.io version",
    )

    return parser
