import ast
import re


def read_os_release() -> dict[str, str]:
    try:
        with open("/etc/os-release") as file:
            contents = file.read()
    except FileNotFoundError:
        with open("/usr/lib/os-release") as file:
            contents = file.read()

    data = dict()

    for line in contents.splitlines():
        line = line.rstrip()
        if not line or line.startswith("#"):
            continue
        if m := re.match(r"([A-Z][A-Z_0-9]+)=(.*)", line):
            name, val = m.groups()
            if val and val[0] in "\"'":
                val = ast.literal_eval(val)
            data[name] = val

    return data


def get_default_target() -> str:
    os_release = read_os_release()
    os_id = os_release.get("ID")

    # ID_LIKE is a space-separated list of identifiers like ID
    os_like = os_release.get("ID_LIKE", "").split()

    # Order matters here!
    if "mageia" in (os_id, *os_like):
        return "mageia"
    elif "fedora" in (os_id, *os_like):
        return "fedora"
    elif "suse" in os_like:
        return "opensuse"
    else:
        return "plain"
