# RPM spec file templates

## Template for Rust crates

### Parameters specific to rust2rpm

| parameter name       | type  | value                                          |
| -------------------- | ----- | ---------------------------------------------- |
| `rust2rpm_version`   | `str` | current major version of rust2rpm              |
| `rust2rpm_target`    | `str` | target OS (fedora, mageia, opensuse, plain)    |
| `rust_packaging_dep` | `str` | dependency string for RPM Rust packaging tools |

### Paramters that control compiler flags

| parameter name              | type            | value                                              |
| --------------------------- | --------------- | -------------------------------------------------- |
| `build_rustflags_debuginfo` | `Optional[int]` | controls the level of debuginfo generated by rustc |

### Parameters for RPM package metadata

| parameter name             | type                   | value                                                                                |
| -------------------------- | ---------------------- | ------------------------------------------------------------------------------------ |
| `rpm_name`                 | `str`                  | RPM source package Name (`rust-{crate}{suffix}`)                                     |
| `rpm_version`              | `str`                  | RPM package Version (translated to RPM format from SemVer)                           |
| `rpm_summary`              | `Optional[str]`        | RPM package summary (derived from `package.description` value from `Cargo.toml`)     |
| `rpm_description`          | `Optional[str]`        | RPM package description (derived from `package.description` value from `Cargo.toml`) |
| `rpm_license`              | `Optional[str]`        | RPM License tag (derived from `package.license` value from `Cargo.toml`)             |
| `rpm_license_comments`     | `Optional[str]`        | additional information returned by license string translation                        |
| `rpm_patch_file_automatic` | `Optional[str]`        | name of the automatically generated patch file                                       |
| `rpm_patch_file_manual`    | `Optional[str]`        | name of the manually generated patch file                                            |
| `rpm_patch_file_comments`  | `list[str]`            | additional lines of comments for the manually generated patch file                   |
| `rpm_buildrequires`        | `list[str]`            | list of RPM `BuildRequires`                                                          |
| `rpm_test_requires`        | `list[str]`            | list of RPM `BuildRequires` that are gated by an `%if %{with check}` conditional     |
| `rpm_requires`             | `dict[str, list[str]]` | map of feature names to lists of RPM `Requires` for library sub-packages             |
| `rpm_provides`             | `dict[str, list[str]]` | map of feature names to lists of RPM `Provides` for library sub-packages             |
| `rpm_license_files`        | `list[str]`            | list of the license files which were detected in crate sources                       |
| `rpm_doc_files`            | `list[str]`            | list of the documentation files which were detected in crate sources                 |
| `rpm_bcond_check`          | `bool`                 | flag to switch default value of the `check` bcond                                    |
| `rpm_test_comments`        | `list[str]`            | comments that document why (specific) tests are disabled                             |
| `rpm_vendor_source`        | `Optional[str]`        | name of the vendor tarball in case vendored sources are used                         |
| `rpm_extra_sources`        | `list[SourceOrPatch]`  | additional source files with number and comments                                     |
| `rpm_extra_patches`        | `list[SourceOrPatch]`  | additional patch files with number and comments                                      |
| `rpm_extra_files`          | `list[str]`            | additional files to be included (only applies if there is a non-devel package)       |

### Parameters that control generation of subpackages

| parameter name            | type                  | value                                                                       |
| ------------------------- | --------------------- | --------------------------------------------------------------------------- |
| `rpm_binary_package`      | `bool`                | `True` if package ships any binaries, `False` for source-only packages      |
| `rpm_binary_package_name` | `str`                 | override name of the binary subpackage (default: `%{crate}`)                |
| `rpm_cdylib_package`      | `bool`                | `True` if package ships any shared libraries (`cdylib` targets)             |
| `rpm_library_package`     | `bool`                | `True` if package has a library component, `False` for binary-only packages |
| `rpm_binary_names`        | `list[str]`           | list of the names of executables which are built from the crate             |
| `crate_features`          | `list[Optional[str]]` | list of names of features for which sub-packages are generated              |
| `cargo_install_lib`       | `bool`                | prevent installation of library sources if `False` (default: `True`)        |
| `cargo_install_bin`       | `bool`                | prevent installation of binary targets if `False` (default: `True`)         |

### Parameters that allow injecting additional commands into scriptlets

| parameter name            | type                  | value                                                         |
| ------------------------- | --------------------- | ------------------------------------------------------------- |
| `rpm_prep_pre`            | `list[str]`           | additional commands that are injected before `%cargo_prep`    |
| `rpm_prep_post`           | `list[str]`           | additional commands that are injected after `%cargo_prep`     |
| `rpm_build_pre`           | `list[str]`           | additional commands that are injected before `%cargo_build`   |
| `rpm_build_post`          | `list[str]`           | additional commands that are injected after `%cargo_build`    |
| `rpm_install_pre`         | `list[str]`           | additional commands that are injected before `%cargo_install` |
| `rpm_install_post`        | `list[str]`           | additional commands that are injected after `%cargo_install`  |
| `rpm_check_pre`           | `list[str]`           | additional commands that are injected before `%cargo_check`   |
| `rpm_check_post`          | `list[str]`           | additional commands that are injected after `%cargo_check`    |

### Parameters for crate metadata

| parameter name     | type            | value                                                     |
| ------------------ | --------------- | --------------------------------------------------------- |
| `crate_name`       | `str`           | crate name (from `Cargo.toml` metadata)                   |
| `crate_version`    | `str`           | crate version (from `Cargo.toml` metadata, SemVer format) |
| `crate_license`    | `Optional[str]` | crate license (from `Cargo.toml` metadata)                |
| `upstream_version` | `str`           | upstream crate version (from `crates.io`)                 |

### Other parameters derived from rust2rpm configuration

| parameter name          | type                   | value                                                                                                                    |
| ----------------------- | ---------------------- | ------------------------------------------------------------------------------------------------------------------------ |
| `conf_buildrequires`    | `list[str]`            | list of additional RPM `BuildRequires` specified in `rust2rpm.toml`                                                      |
| `conf_test_requires`    | `list[str]`            | list of additional RPM `BuildRequires` specified in `rust2rpm.toml` that are gated by an `%if %{with check}` conditional |
| `conf_bin_requires`     | `list[str]`            | list of additional RPM `Requires` for the binary package specified in `rust2rpm.toml`                                    |
| `conf_lib_requires`     | `dict[str, list[str]]` | map of feature names to lists of additional RPM `Requires` for library packages specified in `rust2rpm.toml`             |
| `conf_supported_arches` | `list[str]`            | list of supported architectures (results in `%ifarch` conditionals around `%cargo_build` and `%cargo_test` macros)       |
| `cargo_test_args`       | `list[str]`            | list of arguments that are passed to `%cargo_test`                                                                       |
| `rpm_bin_renames`       | `list[str]`            | list of "mv" commands to rename binaries installed in `%{_bindir}`                                                       |

### Parameters derived from command-line flags

| parameter name               | type   | value                                                                            |
| ---------------------------- | ------ | -------------------------------------------------------------------------------- |
| `cargo_args`                 | `str`  | flags that are added to all `%cargo_foo` macro calls                             |
| `use_relative_license_paths` | `bool` | toggle between relative and absolute paths as arguments for the `%license` macro |
| `use_rpmautospec`            | `bool` | toggle usage of RPMAutospec in generated spec files                              |
| `make_changelog_entry`       | `bool` | toggle creation of changelog entry in generated spec files                       |

### Target-specific parameters

| parameter name           | type   | value                                                           |
| ------------------------ | ------ | --------------------------------------------------------------- |
| `rpm_release`            | `str`  | RPM package Release (exact value depends on the target OS)      |
| `include_build_requires` | `bool` | toggle between dynamically generated and static `BuildRequires` |
| `include_requires`       | `bool` | toggle between dynamically generated and static `Requires`      |
| `include_provides`       | `bool` | toggle between dynamically generated and static `Provides`      |
| `rpm_group`              | `str`  | RPM Group tag (not defined on for all target OS)                |
| `rpm_changelog_date`     | `str`  | date for automatically generated `%changelog` entry             |
| `rpm_changelog_packager` | `str`  | packager for automatically generated `%changelog` entry         |

## Template for non-crate projects (no cargo workspace)

### Parameters specific to rust2rpm

| parameter name       | type  | value                                          |
| -------------------- | ----- | ---------------------------------------------- |
| `rust2rpm_version`   | `str` | current major version of rust2rpm              |
| `rust2rpm_target`    | `str` | target OS (fedora, mageia, opensuse, plain)    |
| `rust_packaging_dep` | `str` | dependency string for RPM Rust packaging tools |

### Paramters that control compiler flags

| parameter name              | type            | value                                              |
| --------------------------- | --------------- | -------------------------------------------------- |
| `build_rustflags_debuginfo` | `Optional[int]` | controls the level of debuginfo generated by rustc |

### Parameters for RPM package metadata

| parameter name             | type                   | value                                                                                |
| -------------------------- | ---------------------- | ------------------------------------------------------------------------------------ |
| `rpm_name`                 | `str`                  | RPM source package Name (`rust-{crate}{suffix}`)                                     |
| `rpm_version`              | `str`                  | RPM package Version (translated to RPM format from SemVer)                           |
| `rpm_summary`              | `Optional[str]`        | RPM package summary (derived from `package.description` value from `Cargo.toml`)     |
| `rpm_description`          | `Optional[str]`        | RPM package description (derived from `package.description` value from `Cargo.toml`) |
| `rpm_url`                  | `Optional[str]`        | URL for the crate (either homepage or repository URL)                                |
| `rpm_source_url`           | `Optional[str]`        | URL for the source of the project                                                    |
| `rpm_license`              | `Optional[str]`        | RPM License tag (derived from `package.license` value from `Cargo.toml`)             |
| `rpm_license_comments`     | `Optional[str]`        | additional information returned by license string translation                        |
| `rpm_patch_file_automatic` | `Optional[str]`        | name of the automatically generated patch file                                       |
| `rpm_patch_file_manual`    | `Optional[str]`        | name of the manually generated patch file                                            |
| `rpm_patch_file_comments`  | `list[str]`            | additional lines of comments for the manually generated patch file                   |
| `rpm_buildrequires`        | `list[str]`            | list of RPM `BuildRequires`                                                          |
| `rpm_test_requires`        | `list[str]`            | list of RPM `BuildRequires` that are gated by an `%if %{with check}` conditional     |
| `rpm_license_files`        | `list[str]`            | list of the license files which were detected in crate sources                       |
| `rpm_doc_files`            | `list[str]`            | list of the documentation files which were detected in crate sources                 |
| `rpm_bcond_check`          | `bool`                 | flag to switch default value of the `check` bcond                                    |
| `rpm_test_comments`        | `list[str]`            | comments that document why (specific) tests are disabled                             |
| `rpm_vendor_source`        | `Optional[str]`        | name of the vendor tarball in case vendored sources are used                         |
| `rpm_extra_sources`        | `list[SourceOrPatch]`  | additional source files with number and comments                                     |
| `rpm_extra_patches`        | `list[SourceOrPatch]`  | additional patch files with number and comments                                      |
| `rpm_extra_files`          | `list[str]`            | additional files to be included in the built package                                 |

### Parameters that control generation of subpackages

| parameter name        | type                  | value                                                                       |
| --------------------- | --------------------- | --------------------------------------------------------------------------- |
| `rpm_binary_package`  | `bool`                | `True` if package ships any binaries, `False` for source-only packages      |
| `rpm_cdylib_package`  | `bool`                | `True` if package ships any shared libraries (`cdylib` targets)             |
| `rpm_binary_names`    | `list[str]`           | list of the names of executables which are built from the crate             |

### Parameters that allow injecting additional commands into scriptlets

| parameter name            | type                  | value                                                         |
| ------------------------- | --------------------- | ------------------------------------------------------------- |
| `rpm_prep_pre`            | `list[str]`           | additional commands that are injected before `%cargo_prep`    |
| `rpm_prep_post`           | `list[str]`           | additional commands that are injected after `%cargo_prep`     |
| `rpm_build_pre`           | `list[str]`           | additional commands that are injected before `%cargo_build`   |
| `rpm_build_post`          | `list[str]`           | additional commands that are injected after `%cargo_build`    |
| `rpm_install_pre`         | `list[str]`           | additional commands that are injected before `%cargo_install` |
| `rpm_install_post`        | `list[str]`           | additional commands that are injected after `%cargo_install`  |
| `rpm_check_pre`           | `list[str]`           | additional commands that are injected before `%cargo_check`   |
| `rpm_check_post`          | `list[str]`           | additional commands that are injected after `%cargo_check`    |

### Parameters for crate metadata

| parameter name     | type            | value                                                     |
| ------------------ | --------------- | --------------------------------------------------------- |
| `crate_version`    | `str`           | crate version (from `Cargo.toml` metadata, SemVer format) |
| `crate_license`    | `Optional[str]` | crate license (from `Cargo.toml` metadata)                |
| `upstream_version` | `str`           | upstream crate version (from `crates.io`)                 |

### Other parameters derived from rust2rpm configuration

| parameter name          | type                   | value                                                                                                                    |
| ----------------------- | ---------------------- | ------------------------------------------------------------------------------------------------------------------------ |
| `conf_buildrequires`    | `list[str]`            | list of additional RPM `BuildRequires` specified in `rust2rpm.toml`                                                      |
| `conf_test_requires`    | `list[str]`            | list of additional RPM `BuildRequires` specified in `rust2rpm.toml` that are gated by an `%if %{with check}` conditional |
| `conf_bin_requires`     | `list[str]`            | list of additional RPM `Requires` for the binary package specified in `rust2rpm.toml`                                    |
| `conf_supported_arches` | `list[str]`            | list of supported architectures (results in `%ifarch` conditionals around `%cargo_build` and `%cargo_test` macros)       |
| `cargo_test_args`       | `list[str]`            | list of arguments that are passed to `%cargo_test`                                                                       |
| `rpm_bin_renames`       | `list[str]`            | list of "mv" commands to rename binaries installed in `%{_bindir}`                                                       |

### Parameters derived from command-line flags

| parameter name               | type   | value                                                                            |
| ---------------------------- | ------ | -------------------------------------------------------------------------------- |
| `cargo_args`                 | `str`  | flags that are added to all `%cargo_foo` macro calls                             |
| `use_rpmautospec`            | `bool` | toggle usage of RPMAutospec in generated spec files                              |
| `make_changelog_entry`       | `bool` | toggle creation of changelog entry in generated spec files                       |

### Target-specific parameters

| parameter name           | type   | value                                                           |
| ------------------------ | ------ | --------------------------------------------------------------- |
| `rpm_release`            | `str`  | RPM package Release (exact value depends on the target OS)      |
| `include_build_requires` | `bool` | toggle between dynamically generated and static `BuildRequires` |
| `rpm_group`              | `str`  | RPM Group tag (not defined on for all target OS)                |
| `rpm_changelog_date`     | `str`  | date for automatically generated `%changelog` entry             |
| `rpm_changelog_packager` | `str`  | packager for automatically generated `%changelog` entry         |

## Template for non-crate projects (with cargo workspace)

### Parameters specific to rust2rpm

| parameter name       | type  | value                                          |
| -------------------- | ----- | ---------------------------------------------- |
| `rust2rpm_version`   | `str` | current major version of rust2rpm              |
| `rust2rpm_target`    | `str` | target OS (fedora, mageia, opensuse, plain)    |
| `rust_packaging_dep` | `str` | dependency string for RPM Rust packaging tools |

### Paramters that control compiler flags

| parameter name              | type            | value                                              |
| --------------------------- | --------------- | -------------------------------------------------- |
| `build_rustflags_debuginfo` | `Optional[int]` | controls the level of debuginfo generated by rustc |

### Parameters for RPM package metadata

| parameter name             | type                   | value                                                                                |
| -------------------------- | ---------------------- | ------------------------------------------------------------------------------------ |
| `rpm_name`                 | `str`                  | RPM source package Name (`rust-{crate}{suffix}`)                                     |
| `rpm_version`              | `str`                  | RPM package Version (translated to RPM format from SemVer)                           |
| `rpm_summary`              | `Optional[str]`        | RPM package summary (derived from `package.description` value from `Cargo.toml`)     |
| `rpm_description`          | `Optional[str]`        | RPM package description (derived from `package.description` value from `Cargo.toml`) |
| `rpm_url`                  | `Optional[str]`        | URL for the crate (either homepage or repository URL)                                |
| `rpm_source_url`           | `Optional[str]`        | URL for the source of the project                                                    |
| `rpm_license`              | `Optional[str]`        | RPM License tag (derived from `package.license` value from `Cargo.toml`)             |
| `rpm_license_comments`     | `Optional[str]`        | additional information returned by license string translation                        |
| `rpm_buildrequires`        | `list[str]`            | list of RPM `BuildRequires`                                                          |
| `rpm_test_requires`        | `list[str]`            | list of RPM `BuildRequires` that are gated by an `%if %{with check}` conditional     |
| `rpm_license_files`        | `list[str]`            | list of the license files which were detected in crate sources                       |
| `rpm_doc_files`            | `list[str]`            | list of the documentation files which were detected in crate sources                 |
| `rpm_binary_names`         | `list[str]`            | list of the names of executables which are built from the project                    |
| `rpm_cdylib_package`       | `bool`                 | `True` if package ships any shared libraries (`cdylib` targets)                      |
| `rpm_bcond_check`          | `bool`                 | flag to switch default value of the `check` bcond                                    |
| `rpm_test_comments`        | `list[str]`            | comments that document why (specific) tests are disabled                             |
| `rpm_vendor_source`        | `Optional[str]`        | name of the vendor tarball in case vendored sources are used                         |
| `rpm_extra_sources`        | `list[SourceOrPatch]`  | additional source files with number and comments                                     |
| `rpm_extra_patches`        | `list[SourceOrPatch]`  | additional patch files with number and comments                                      |
| `rpm_extra_files`          | `list[str]`            | additional files to be included in the built package                                 |

### Parameters that allow injecting additional commands into scriptlets

| parameter name            | type                  | value                                                         |
| ------------------------- | --------------------- | ------------------------------------------------------------- |
| `rpm_prep_pre`            | `list[str]`           | additional commands that are injected before `%cargo_prep`    |
| `rpm_prep_post`           | `list[str]`           | additional commands that are injected after `%cargo_prep`     |
| `rpm_build_pre`           | `list[str]`           | additional commands that are injected before `%cargo_build`   |
| `rpm_build_post`          | `list[str]`           | additional commands that are injected after `%cargo_build`    |
| `rpm_install_pre`         | `list[str]`           | additional commands that are injected before `%cargo_install` |
| `rpm_install_post`        | `list[str]`           | additional commands that are injected after `%cargo_install`  |
| `rpm_check_pre`           | `list[str]`           | additional commands that are injected before `%cargo_check`   |
| `rpm_check_post`          | `list[str]`           | additional commands that are injected after `%cargo_check`    |

### Other parameters derived from rust2rpm configuration

| parameter name       | type                   | value                                                                                                                    |
| -------------------- | ---------------------- | ------------------------------------------------------------------------------------------------------------------------ |
| `conf_buildrequires` | `list[str]`            | list of additional RPM `BuildRequires` specified in `rust2rpm.toml`                                                      |
| `conf_test_requires` | `list[str]`            | list of additional RPM `BuildRequires` specified in `rust2rpm.toml` that are gated by an `%if %{with check}` conditional |
| `conf_bin_requires`  | `list[str]`            | list of additional RPM `Requires` for the binary package specified in `rust2rpm.toml`                                    |
| `cargo_test_args`    | `list[str]`            | list of arguments that are passed to `%cargo_test`                                                                       |
| `rpm_bin_renames`       | `list[str]`            | list of "mv" commands to rename binaries installed in `%{_bindir}`                                                       |

### Parameters derived from command-line flags

| parameter name               | type   | value                                                                            |
| ---------------------------- | ------ | -------------------------------------------------------------------------------- |
| `cargo_args`                 | `str`  | flags that are added to all `%cargo_foo` macro calls                             |
| `use_rpmautospec`            | `bool` | toggle usage of RPMAutospec in generated spec files                              |
| `make_changelog_entry`       | `bool` | toggle creation of changelog entry in generated spec files                       |

### Target-specific parameters

| parameter name           | type   | value                                                           |
| ------------------------ | ------ | --------------------------------------------------------------- |
| `rpm_release`            | `str`  | RPM package Release (exact value depends on the target OS)      |
| `include_build_requires` | `bool` | toggle between dynamically generated and static `BuildRequires` |
| `rpm_group`              | `str`  | RPM Group tag (not defined on for all target OS)                |
| `rpm_changelog_date`     | `str`  | date for automatically generated `%changelog` entry             |
| `rpm_changelog_packager` | `str`  | packager for automatically generated `%changelog` entry         |

